@@ -28,6 +28,8 @@ class ListoApi():
         self.Suppliers = _suppliers(token, base_url)
         self.ExchangeRate = _er(token, base_url)
         self.CashAdvances = _cash_advances(token, base_url)
+        self.Filings = _banks(token, base_url)
+        self.Reports = _banks(token, base_url)
         if is_vault:
             self.InvoicingVault = _invoicing_vault(token, base_url, certificate_num)
         if cer_path and key_path and key_passphrase:
